## Larousse API

### Why ?
Because the Larousse website doesn't supply an api to look up definitions :(

### How ?
* python3
* requests
* re
* BeautifulSoup

### Possible improvements
* Suggest words if the word is misspelled
* Turn this into an actual pip package for ease of use